==> haskell-hslua-aeson-2.3.0.1-28-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hslua-aeson
version:              2.3.0.1
visibility:           public
id:                   hslua-aeson-2.3.0.1-KZvmnOUsO8FBnGAQT19lxr
key:                  hslua-aeson-2.3.0.1-KZvmnOUsO8FBnGAQT19lxr
license:              MIT
copyright:            © 2017–2023 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Allow aeson data types to be used with Lua.
description:
    This package provides instances to push and receive any
    datatype encodable as JSON to and from the Lua stack.

category:             Foreign
abi:                  c3a3178156d2447103be15869c5a25f1
exposed:              True
exposed-modules:      HsLua.Aeson
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hslua-aeson-2.3.0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hslua-aeson-2.3.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-aeson
hs-libraries:         HShslua-aeson-2.3.0.1-KZvmnOUsO8FBnGAQT19lxr
depends:
    aeson-2.1.2.1-2DC8oo6JY6hDnCPVtrY9Cs base-4.16.4.0
    bytestring-0.11.4.0 containers-0.6.5.1
    hashable-1.4.3.0-3dqA7o3S1KBIuEdO2YDkYf
    hslua-core-2.3.1-BdJuYzCcbyqGx8Hg4w28gu
    hslua-marshalling-2.3.0-q2eUvveTlp4XHhxsQ8QDY mtl-2.2.2
    scientific-0.3.7.0-4N3HWbhhMZ4D2PBnQaMqAR text-1.2.5.0
    unordered-containers-0.2.20-2sfG1n18ekp4kj5cDOH71Y
    vector-0.13.1.0-BOAscM7GxpQxkvUjpqER4

haddock-interfaces:   /usr/share/doc/haskell-hslua-aeson/html/hslua-aeson.haddock
haddock-html:         /usr/share/doc/haskell-hslua-aeson/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-aeson-2.3.0.1-29-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hslua-aeson
version:              2.3.0.1
visibility:           public
id:                   hslua-aeson-2.3.0.1-8SpoJZsVhZZ4HdKbcO42Qt
key:                  hslua-aeson-2.3.0.1-8SpoJZsVhZZ4HdKbcO42Qt
license:              MIT
copyright:            © 2017–2023 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Allow aeson data types to be used with Lua.
description:
    This package provides instances to push and receive any
    datatype encodable as JSON to and from the Lua stack.

category:             Foreign
abi:                  a5e210b9d9085da80001ddbffa54d1c3
exposed:              True
exposed-modules:      HsLua.Aeson
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hslua-aeson-2.3.0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hslua-aeson-2.3.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-aeson
hs-libraries:         HShslua-aeson-2.3.0.1-8SpoJZsVhZZ4HdKbcO42Qt
depends:
    aeson-2.1.2.1-3SHm0QLDkzeAZY7TeIq3Kg base-4.16.4.0
    bytestring-0.11.4.0 containers-0.6.5.1
    hashable-1.4.3.0-4gqtyFKn8Wu9OwsZtyYGdt
    hslua-core-2.3.1-AibN0M96j7iBmbaG4dDadO
    hslua-marshalling-2.3.0-CiwdAA8j4TSFzpfXcFFw72 mtl-2.2.2
    scientific-0.3.7.0-72r9rPpXaeUjwM4XNBSJR text-1.2.5.0
    unordered-containers-0.2.20-8WFaf62MVyiL1uC2m0h0zY
    vector-0.13.1.0-FuSYSqJEiCU51oStZmHlCe

haddock-interfaces:   /usr/share/doc/haskell-hslua-aeson/html/hslua-aeson.haddock
haddock-html:         /usr/share/doc/haskell-hslua-aeson/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
